==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/Actions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AssignUserToRealm;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Actions
 */
@JsonPropertyOrder({ Actions.JSON_PROPERTY_ASSIGN_USER_TO_REALM })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class Actions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGN_USER_TO_REALM = "assignUserToRealm";
    private AssignUserToRealm assignUserToRealm;

    public Actions() {
    }

    public Actions assignUserToRealm(AssignUserToRealm assignUserToRealm) {

        this.assignUserToRealm = assignUserToRealm;
        return this;
    }

    /**
     * Get assignUserToRealm
     *
     * @return assignUserToRealm
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AssignUserToRealm getAssignUserToRealm() {
        return assignUserToRealm;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignUserToRealm(AssignUserToRealm assignUserToRealm) {
        this.assignUserToRealm = assignUserToRealm;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Actions actions = (Actions) o;
        return Objects.equals(this.assignUserToRealm, actions.assignUserToRealm);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignUserToRealm);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Actions {\n");
        sb.append("    assignUserToRealm: ").append(toIndentedString(assignUserToRealm)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/Actions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AssignUserToRealm;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Actions
 */
@JsonPropertyOrder({ Actions.JSON_PROPERTY_ASSIGN_USER_TO_REALM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class Actions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGN_USER_TO_REALM = "assignUserToRealm";
    private AssignUserToRealm assignUserToRealm;

    public Actions() {
    }

    public Actions assignUserToRealm(AssignUserToRealm assignUserToRealm) {

        this.assignUserToRealm = assignUserToRealm;
        return this;
    }

    /**
     * Get assignUserToRealm
     *
     * @return assignUserToRealm
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AssignUserToRealm getAssignUserToRealm() {
        return assignUserToRealm;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGN_USER_TO_REALM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignUserToRealm(AssignUserToRealm assignUserToRealm) {
        this.assignUserToRealm = assignUserToRealm;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Actions actions = (Actions) o;
        return Objects.equals(this.assignUserToRealm, actions.assignUserToRealm);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignUserToRealm);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Actions {\n");
        sb.append("    assignUserToRealm: ").append(toIndentedString(assignUserToRealm)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
